<?php

/*
 * This file is part of the PHP CS utility.
 *
 * (c) Fabien Potencier <fabien@symfony.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace Symfony\CS\Tests\Fixer\Symfony;

use Symfony\CS\Tests\Fixer\AbstractFixerTestBase;

final class MethodArgumentDefaultValueFixerTest extends AbstractFixerTestBase
{
    /**
     * @dataProvider provideExamplesForAllVersions
     *
     * @param string      $expected
     * @param string|null $input
     */
    public function testFixForAllVersions($expected, $input = null)
    {
        $this->makeTest($expected, $input);
    }

    /**
     * @return array
     */
    public function provideExamplesForAllVersions()
    {
        return array(
            array(
                '<?php function bFunction($foo, $bar) {}',
                '<?php function bFunction($foo = null, $bar) {}',
            ),
            array(
                '<?php function bFunction($foo, $bar) {}',
                '<?php function bFunction($foo = "two words", $bar) {}',
            ),
            array(
                '<?php function cFunction($foo, $bar, $baz) {}',
                '<?php function cFunction($foo = false, $bar = "bar", $baz) {}',
            ),
            array(
                '<?php function dFunction($foo, $bar, $baz) {}',
                '<?php function dFunction($foo = false, $bar, $baz) {}',
            ),
            array(
                '<?php function foo (Foo $bar = null, $baz) {}',
            ),
            array(
                '<?php function eFunction($foo, $bar, \SplFileInfo $baz, $x = "default") {}',
                '<?php function eFunction($foo, $bar = "removedDefault", \SplFileInfo $baz, $x = "default") {}',
            ),
            array(
                <<<'EOT'
                    <?php
                        function eFunction($foo, $bar, \SplFileInfo $baz, $x = 'default') {};

                        function fFunction($foo, $bar, \SplFileInfo $baz, $x = 'default') {};
EOT
                ,
                <<<'EOT'
                    <?php
                        function eFunction($foo, $bar, \SplFileInfo $baz, $x = 'default') {};

                        function fFunction($foo, $bar = 'removedValue', \SplFileInfo $baz, $x = 'default') {};
EOT
            ),
            array(
                '<?php function foo ($bar /* a */ /* b */, $c) {}',
                '<?php function foo ($bar /* a */ = /* b */ 1, $c) {}',
            ),
            array(
                '<?php function hFunction($foo,$bar,\SplFileInfo $baz,$x = 5) {};',
                '<?php function hFunction($foo,$bar="removedValue",\SplFileInfo $baz,$x = 5) {};',
            ),
            array(
                '<?php function eFunction($foo, $bar, \SplFileInfo $baz = null, $x) {}',
                '<?php function eFunction($foo = PHP_EOL, $bar, \SplFileInfo $baz = null, $x) {}',
            ),
            array(
                '<?php function eFunction($foo, $bar) {}',
                '<?php function eFunction($foo       = null, $bar) {}',
            ),
            array(
                <<<'EOT'
                    <?php
                        function foo(
                            $a, // test
                            $b, /* test */
                            $c, // abc
                            $d
                        ) {}
EOT
            ,
                <<<'EOT'
                    <?php
                        function foo(
                            $a = 1, // test
                            $b = 2, /* test */
                            $c = null, // abc
                            $d
                        ) {}
EOT
            ),
            array(
                '<?php function foo($foo, $bar) {}',
                '<?php function foo($foo = array(array(1)), $bar) {}',
            ),
            array(
                '<?php function a($a, $b) {}',
                '<?php function a($a = array("a" => "b", "c" => "d"), $b) {}',
            ),
            array(
                '<?php function a($a, $b) {}',
                '<?php function a($a = ["a" => "b", "c" => "d"], $b) {}',
            ),
            array(
                '<?php function a($a, $b) {}',
                '<?php function a($a = NULL, $b) {}',
            ),
            array(
                '<?php function a(\SplFileInfo $a = Null, $b) {}',
            ),
            array(
                '<?php function a(array $a = null, $b) {}',
            ),
            array(
                '<?php function a(callable $a = null, $b) {}',
            ),
            array(
                '<?php function a(\SplFileInfo &$a = Null, $b) {}',
            ),
            array(
                '<?php function a(&$a, $b) {}',
                '<?php function a(&$a = null, $b) {}',
            ),
            array(
                '<?php function a($a = 1, ...$b) {}',
            ),
            array(
                '<?php function a($a = 1, \SplFileInfo ...$b) {}',
            ),
            array(
                '<?php function ($a, $b = 1) use ($c) {}',
            ),
            array(
                '<?php function ($a, $b) use ($c) {}',
                '<?php function ($a = 1, $b) use ($c) {}',
            ),
        );
    }
}
